__author__ = 'ugursogukpinar'

__TMPFOLDERS__ = {
    'posix'  : '/tmp/VHCreator/',
    'nt' : 'C:/tmp/VHCreator/'
}

__ERRORS__ = {
    'filenotfound' : 'There is no {folderName} folder in {directory}',
    'clonfail' : 'Clonning failed'
}
import subprocess,sys
class Git(object):

    def __init__(self,repoUrl,folderName,serverDirectory):
        # target folder to clone repository.
        self.folderName = folderName
        # Given directory. It should contain folderName
        self.directory = serverDirectory

        folderIndex = self.checkFolderName(self.folderName,self.directory)
        fullPath = self.createFullPath(folderIndex)
        self.execute('clone',repoUrl,fullPath)



    # Is there the folder name on path?
    def checkFolderName(self,folderName,serverDirectory):

        allFolders = serverDirectory.split('/')
        i = 0
        while((i < len(allFolders)) and (folderName != allFolders[i])):
            i += 1


        if(i == len(allFolders)):
            # Foldername not found.
            print __ERRORS__['filenotfound'].format(directory = serverDirectory,folderName = folderName)
            print __ERRORS__['clonfail']
            sys.exit(2)
        else:
            # Return folder index.
            return i+1


    # Create full path of found folder.
    def createFullPath(self,index):
        allFolders = self.directory.split('/')
        return '/'.join(allFolders[0:index])

    def execute(self,*args):
        try:
            subprocess.check_call(['git'] + list(args))
        except:
            print "Unexpected error: ",sys.exc_info()[0]
            sys.exit(2)





#!/usr/bin/env python
#-*-coding:utf-8-*-


__AUTHOR__ = 'ugursogukpinar'

__TMPFILES__ = {
    'posix'  : '/tmp/VHCreator/VHCreator.conf',
    'nt' : 'C:/tmp/VHCreator/VHCreator.conf'
}

__ERRORS__ = {
    'conffilenotfound' : '{0} file not found. You have to give configuration file path.',
    'conffilecantwrite' : 'Default configuration could not save to {0}',
    'requiredfoldername' : 'You must give foldername with -f operator to clone directory'
}

__VERSION__ = '0.1.3'

import argparse,os,sys


class Arguments(object):

    def __init__(self):
        parser = argparse.ArgumentParser()
        parser.add_argument('servername',help='VirtualHost server name')
        parser.add_argument('directory', help='VirtualHost document root')
        parser.add_argument('-cf','--conf',help='VirtualHosts configuration file path.',default=False)
        parser.add_argument('-ho','--host', action="store_true" , help='With this option you can insert your server name into hosts file.',default=False)
        parser.add_argument('-v','--version',action="version", help="Version",version='%s' % (__VERSION__))

        parser.add_argument('-r','--repo',help='Git repository url to clone given directory',default=False)
        parser.add_argument('-f','--foldername',help="Foldername define which folder will use on cloning.")

        self.args = parser.parse_args()

        if(self.args.conf):
            self.setConfFile(self.args.conf)
        else:
            self.args.conf = self.getConfFilePath()

        if(self.args.repo):
            if(not self.args.foldername):
                self.returnError('requiredfoldername')


    def getArgs(self):
        return self.args

    def getConfFilePath(self):
        try:
            tmpFile = open(__TMPFILES__[os.name],'r')
            confFilePath = tmpFile.readline().strip()
            return confFilePath
        except:
            self.returnError('conffilenotfound',list(__TMPFILES__[os.name]))


    def setConfFile(self,confFilePath):
        try:
            tmpFile = open(__TMPFILES__[os.name],'w')
            tmpFile.write(confFilePath)
            tmpFile.close()
        except:
            print __ERRORS__['conffilecantwrite'].format(__TMPFILES__[os.name])



    def returnError(self,errorcode,*args):
        errorStr = __ERRORS__[errorcode]

        if(len(args)):
            for arg in args:
                errorStr.format(arg)

        print errorStr
        sys.exit(2) #Return with exit



#!/usr/bin/env python
#-*-coding:utf-8-*-

__AUTHOR__ = 'ugursogukpinar'


from arguments import Arguments
from VHCreator import VHCreator
from git import Git

def main():
    __Arguments = Arguments()
    args = __Arguments.getArgs()

    __VHCreator = VHCreator(args.conf,args.directory)
    __VHCreator.addVirtualHost(args.servername)

    if(args.host):
        __VHCreator.addHostName(args.servername)

    if(args.repo):
        Git(args.repo,args.foldername,args.directory)

if __name__ == "__main__":
    main()




#!/usr/bin/env python
#-*-coding:utf-8-*-
__AUTHOR__ = 'ugursogukpinar'


import os,sys

__ERRORS__ = {
    'notfound' : '\n{} file not found.',
    'notopen' : '\n{} can\'t open. Try with root priviliges.'
}

__VIRTUALHOST__ = '''\n
    # Added with VHCreator
    # Alias of VirtualHost \'{3}\'
    <VirtualHost *:{0}>
        DocumentRoot {1}
        ServerName {2}
    </VirtualHost>
\n'''

__ETCHOSTS__ = {
    'posix' : '/etc/hosts',
    'nt' : 'C:\Windows\System32\Drivers\etc\hosts'
}

__HOSTNAME__ = '\n{0}         {1}\n'

class VHCreator(object):
    def __init__(self,configFilePath,virtualHostDirectory):
        self.configFilePath = configFilePath
        self.virtualHostDirectory = virtualHostDirectory
        self.checkPathsExist(self.configFilePath)

    # Check configuration file exist
    def checkPathsExist(self,filePath):
        if(os.path.isfile(filePath) == False):
            print __ERRORS__['notfound'].format(filePath)
            sys.exit(2) #  Return with exit


    # Add virtual host script to conf file
    def addVirtualHost(self,serverName,serverPort=80,alias=''):
        virtualHostStr = __VIRTUALHOST__.format(serverPort,self.virtualHostDirectory,serverName,alias)
        self.writeToFile(self.configFilePath,virtualHostStr)


    # Add /etc/hosts (posix) server name
    def addHostName(self,serverName):
        hostsFilePath = __ETCHOSTS__[os.name.strip()]
        self.checkPathsExist(hostsFilePath)
        hostString = __HOSTNAME__.format('127.0.0.1',serverName)
        self.writeToFile(hostsFilePath,hostString)


    # Write given string to given file
    def writeToFile(self,fileDirectory,string):
        try:
            file = open(fileDirectory,'a')
            file.write(string)
            file.flush()
            file.close()
        except:
            print __ERRORS__['notopen'].format(fileDirectory)
            sys.exit(2)# Return with exit






#-*-coding:utf-8-*-
import sys
from setuptools import *

setup(
    name="VHCreator",
    version="0.2.0",
    author="Uğur Soğukpınar",
    author_email="sogukpinar.ugur@gmail.com",
    url="https://github.com/ugursogukpinar/VHCreator",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "vhcreator = scripts.__main__:main",
        ],
    },
    license="LICENSE.txt",
    description="VirtualHost manager",
    long_description=open("README.txt").read(),
    install_requires=list(filter(None, [
        "argparse" if sys.version_info[:2] < (2, 7) else None,
    ])),
)
